Class: Teams::Cards::Container

Inherits:
CardElement show all
Defined in:
lib/teams/cards/generated.rb

Overview

A container for other elements. Use containers for styling purposes and/or to logically group a set of elements together, which can be especially useful when used with Action.ToggleVisibility.

Constant Summary

Constants inherited from GeneratedCard

GeneratedCard::OMIT

Method Summary

Methods inherited from GeneratedCard

array_adder, card_fields, field, #initialize, positional_field, splat_field, #to_h, #to_json

Constructor Details

This class inherits a constructor from Teams::Cards::GeneratedCard