Class: Teams::Cards::SubmitAction
- Inherits:
-
Action
- Object
- GeneratedCard
- SerializableObject
- Action
- Teams::Cards::SubmitAction
- Defined in:
- lib/teams/cards/generated.rb
Overview
Gathers input values, merges them with the data property if specified, and sends them to the Bot via an Invoke activity. The Bot can only acknowledge is has received the request.
Constant Summary
Constants inherited from GeneratedCard
Method Summary
Methods inherited from GeneratedCard
array_adder, card_fields, field, #initialize, positional_field, splat_field, #to_h, #to_json
Constructor Details
This class inherits a constructor from Teams::Cards::GeneratedCard